@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,8 +58,11 @@ import com.openexchange.config.Reloadable;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.mail.transport.TransportProvider;
+import com.openexchange.mail.transport.listener.MailTransportListener;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.osgi.RankingAwareNearRegistryServiceTracker;
+import com.openexchange.smtp.ListenerChain;
 import com.openexchange.smtp.SMTPProvider;
 import com.openexchange.smtp.SmtpReloadable;
 import com.openexchange.smtp.services.Services;
@@ -91,6 +94,10 @@ public final class SMTPActivator extends HousekeepingActivator {
         try {
             Services.setServiceLookup(this);
 
+            RankingAwareNearRegistryServiceTracker<MailTransportListener> listing = new RankingAwareNearRegistryServiceTracker<MailTransportListener>(context, MailTransportListener.class);
+            ListenerChain.initInstance(listing);
+            rememberTracker(listing);
+
             trackService(HostnameService.class);
             track(MailcapCommandMap.class, new MailcapServiceTracker(context));
             openTrackers();
@@ -110,6 +117,7 @@ public final class SMTPActivator extends HousekeepingActivator {
     @Override
     public void stopBundle() throws Exception {
         try {
+            ListenerChain.releaseInstance();
             cleanUp();
             Services.setServiceLookup(null);
         } catch (final Throwable t) {
